==> jd-sdk-1.0.3.tar.gz: jd-sdk-1.0.3/jd/api/rest/__init__.py <==
from jd.api.rest.ComEpiPromoOpenApiWriteCreateSuitPromoRequest import ComEpiPromoOpenApiWriteCreateSuitPromoRequest
from jd.api.rest.ComJdStockShopGlobalWebOpenWarehouseFacadeAddStoreRequest import ComJdStockShopGlobalWebOpenWarehouseFacadeAddStoreRequest
from jd.api.rest.ComJdThPopOpenOrderDeliveryFacadeSplitOrderRequest import ComJdThPopOpenOrderDeliveryFacadeSplitOrderRequest
from jd.api.rest.ComJdThPopOpenOrderInformationFacadeQueryPaymentDetailInfoRequest import ComJdThPopOpenOrderInformationFacadeQueryPaymentDetailInfoRequest
from jd.api.rest.ComJdOverseaApiProductUpdateApiServiceRequest import ComJdOverseaApiProductUpdateApiServiceRequest
from jd.api.rest.ComJdSellerOrderApiDeliveryFacadeDeliveryRequest import ComJdSellerOrderApiDeliveryFacadeDeliveryRequest
from jd.api.rest.ComJdJinVenderHandlerOpenStatementFacadeStatementDetailRequest import ComJdJinVenderHandlerOpenStatementFacadeStatementDetailRequest
from jd.api.rest.ComJdOverseaApiProductUpdateApiServiceDeleteSkuRequest import ComJdOverseaApiProductUpdateApiServiceDeleteSkuRequest
from jd.api.rest.ComProductUpdateApiServiceUpdateSpuRequest import ComProductUpdateApiServiceUpdateSpuRequest
from jd.api.rest.VenderGetVenderCategoryByVenderIdI18NRequest import VenderGetVenderCategoryByVenderIdI18NRequest
from jd.api.rest.VenderSellerWebControllerOpenCompanyVenderCompanyFacadeGetCompanyByVenderIdRequest import VenderSellerWebControllerOpenCompanyVenderCompanyFacadeGetCompanyByVenderIdRequest
from jd.api.rest.ComJdThPopOpenOrderInformationFacadeListOrderRequest import ComJdThPopOpenOrderInformationFacadeListOrderRequest
from jd.api.rest.ComProductUpdateApiServiceUpdateSkusRequest import ComProductUpdateApiServiceUpdateSkusRequest
from jd.api.rest.ThSellerPopUpdateStoreSkuPriceRequest import ThSellerPopUpdateStoreSkuPriceRequest
from jd.api.rest.ThSellerPopUpdateStoreSkuStockRequest import ThSellerPopUpdateStoreSkuStockRequest
from jd.api.rest.ComJdThPopOpenOrderPrintFacadePrintLabelRequest import ComJdThPopOpenOrderPrintFacadePrintLabelRequest
from jd.api.rest.ComJdSellerOrderApiPrintFacadePrintRequest import ComJdSellerOrderApiPrintFacadePrintRequest
from jd.api.rest.ComEpiCouponOpenApiReadCouponDetailRequest import ComEpiCouponOpenApiReadCouponDetailRequest
from jd.api.rest.ComProductUpdateApiServiceSaveProductRequest import ComProductUpdateApiServiceSaveProductRequest
from jd.api.rest.VenderGetVenderShopCategoryByVenderIdI18NRequest import VenderGetVenderShopCategoryByVenderIdI18NRequest
from jd.api.rest.ComProductQueryApiServiceQuerycategoryRequest import ComProductQueryApiServiceQuerycategoryRequest
from jd.api.rest.ComJdSellerOrderApiOperationFacadeAcceptOrderRequest import ComJdSellerOrderApiOperationFacadeAcceptOrderRequest
from jd.api.rest.ComJdIntlAsmShopAfsApiServiceQueryDetailRequest import ComJdIntlAsmShopAfsApiServiceQueryDetailRequest
from jd.api.rest.ComJdwlApiOrderTrackSiteJsfExportOrderTrackSiteExportAddIntlOrderTrackRequest import ComJdwlApiOrderTrackSiteJsfExportOrderTrackSiteExportAddIntlOrderTrackRequest
from jd.api.rest.ComJdSellerOrderApiOperationFacadeRecallOrderRequest import ComJdSellerOrderApiOperationFacadeRecallOrderRequest
from jd.api.rest.ComProductQueryApiServiceQueryskusRequest import ComProductQueryApiServiceQueryskusRequest
from jd.api.rest.ComJdSellerOrderApiOperationFacadeVerifyOrderRequest import ComJdSellerOrderApiOperationFacadeVerifyOrderRequest
from jd.api.rest.ComEpiPromoOpenApiWriteCreateSumPromoRequest import ComEpiPromoOpenApiWriteCreateSumPromoRequest
from jd.api.rest.ComEpiCouponOpenApiReadCouponListRequest import ComEpiCouponOpenApiReadCouponListRequest
from jd.api.rest.ComProductQueryApiServiceQueryProductByIdRequest import ComProductQueryApiServiceQueryProductByIdRequest
from jd.api.rest.JosVoucherInfoGetRequest import JosVoucherInfoGetRequest
from jd.api.rest.ComJdwlSellerAlphaOpenServiceGetDeliveryRecommendCarriersForOpenRequest import ComJdwlSellerAlphaOpenServiceGetDeliveryRecommendCarriersForOpenRequest
from jd.api.rest.ComEpiPromoOpenApiWriteDelPromoRequest import ComEpiPromoOpenApiWriteDelPromoRequest
from jd.api.rest.CommonImageUploadFileRequest import CommonImageUploadFileRequest
from jd.api.rest.ComJdThPopOpenOrderPrintFacadeGetOrderShippingListRequest import ComJdThPopOpenOrderPrintFacadeGetOrderShippingListRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetUnitPromoRequest import ComEpiPromoOpenApiReadGetUnitPromoRequest
from jd.api.rest.PopAdminExportQueryListNewRequest import PopAdminExportQueryListNewRequest
from jd.api.rest.ComJdPopVenderCenterI18nApiVenderVenderBasicFacadeGetVenderInfoByVenderIdRequest import ComJdPopVenderCenterI18nApiVenderVenderBasicFacadeGetVenderInfoByVenderIdRequest
from jd.api.rest.ComJdIntlAsmShopAfsApiServiceQueryAllRequest import ComJdIntlAsmShopAfsApiServiceQueryAllRequest
from jd.api.rest.JosMasterKeyGetRequest import JosMasterKeyGetRequest
from jd.api.rest.ComJdThPopOpenOrderInformationFacadeQueryOrderDetailRequest import ComJdThPopOpenOrderInformationFacadeQueryOrderDetailRequest
from jd.api.rest.I18nPlaceOrderServiceJsfGetPreWaybillCodeForOpenApiRequest import I18nPlaceOrderServiceJsfGetPreWaybillCodeForOpenApiRequest
from jd.api.rest.ComJdJinVenderHandlerOpenStatementFacadeListStatementRequest import ComJdJinVenderHandlerOpenStatementFacadeListStatementRequest
from jd.api.rest.ComJdAddressInternationalGlscGlscAddressCodingServiceWSGetChildrenRequest import ComJdAddressInternationalGlscGlscAddressCodingServiceWSGetChildrenRequest
from jd.api.rest.ComJdAddressInternationalGlscGlscAddressCodingServiceWSParseAddressCodingRequest import ComJdAddressInternationalGlscGlscAddressCodingServiceWSParseAddressCodingRequest
from jd.api.rest.JosSecretApiReportGetRequest import JosSecretApiReportGetRequest
from jd.api.rest.ComProductQueryApiServiceQuerySkusByOuterIdsRequest import ComProductQueryApiServiceQuerySkusByOuterIdsRequest
from jd.api.rest.ComJdAdwordApiServiceAdwordSellerApiServiceCreateAdwordForSkuRequest import ComJdAdwordApiServiceAdwordSellerApiServiceCreateAdwordForSkuRequest
from jd.api.rest.ComJdAdwordApiServiceAdwordSellerApiServiceQueryAdwordsBySkuIdRequest import ComJdAdwordApiServiceAdwordSellerApiServiceQueryAdwordsBySkuIdRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetPromoMainSkuRequest import ComEpiPromoOpenApiReadGetPromoMainSkuRequest
from jd.api.rest.ComJdAdwordApiServiceAdwordSellerApiServiceDeleteAdwordsBySkuIdRequest import ComJdAdwordApiServiceAdwordSellerApiServiceDeleteAdwordsBySkuIdRequest
from jd.api.rest.ComEpiBranchOpenApiReadBranchListRequest import ComEpiBranchOpenApiReadBranchListRequest
from jd.api.rest.StockUpdateSkuStockRequest import StockUpdateSkuStockRequest
from jd.api.rest.ComJdPopVenderCenterI18nApiBusinessBusinessCheckFacadeRequest import ComJdPopVenderCenterI18nApiBusinessBusinessCheckFacadeRequest
from jd.api.rest.ComEpiBranchOpenApiReadBranchDetailRequest import ComEpiBranchOpenApiReadBranchDetailRequest
from jd.api.rest.ComEpiBranchOpenApiWriteBranchCreationRequest import ComEpiBranchOpenApiWriteBranchCreationRequest
from jd.api.rest.JingdongComEpiBranchOpenApiWriteBranchModifyRequest import JingdongComEpiBranchOpenApiWriteBranchModifyRequest
from jd.api.rest.StockAddWareStockRequest import StockAddWareStockRequest
from jd.api.rest.ComEpiBranchOpenApiWriteUpdateStatusRequest import ComEpiBranchOpenApiWriteUpdateStatusRequest
from jd.api.rest.ComJdSellerTrackApiTrackSynFacadeRequest import ComJdSellerTrackApiTrackSynFacadeRequest
from jd.api.rest.StockGetStoreListRequest import StockGetStoreListRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetGiftPromoRequest import ComEpiPromoOpenApiReadGetGiftPromoRequest
from jd.api.rest.PromotionPriceUpdateSkuPriceJsonWithVenderIdRequest import PromotionPriceUpdateSkuPriceJsonWithVenderIdRequest
from jd.api.rest.StockBatchQueryStockRequest import StockBatchQueryStockRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetSuitPromoRequest import ComEpiPromoOpenApiReadGetSuitPromoRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetPromoListForPageRequest import ComEpiPromoOpenApiReadGetPromoListForPageRequest
from jd.api.rest.ComJdPopVenderCenterI18nApiShopVenderShopFacadeGetVenderShopByVenderIdRequest import ComJdPopVenderCenterI18nApiShopVenderShopFacadeGetVenderShopByVenderIdRequest
from jd.api.rest.VenderSellerWebControllerOpenVenderAddrVenderAddrFacadeListVenderTakeAddressRequest import VenderSellerWebControllerOpenVenderAddrVenderAddrFacadeListVenderTakeAddressRequest
from jd.api.rest.VenderSellerWebControllerOpenVenderAddrVenderAddrFacadeListVenderReturnAddressRequest import VenderSellerWebControllerOpenVenderAddrVenderAddrFacadeListVenderReturnAddressRequest
from jd.api.rest.ComJdGmsGreatdaneCategoryServiceReadCategoryReadServiceGetCategorysRequest import ComJdGmsGreatdaneCategoryServiceReadCategoryReadServiceGetCategorysRequest
from jd.api.rest.ComJdJinVenderHandlerOpenStatementFacadeConfirmStatementRequest import ComJdJinVenderHandlerOpenStatementFacadeConfirmStatementRequest
from jd.api.rest.PopAdminExportOrderDeliveryNewRequest import PopAdminExportOrderDeliveryNewRequest
from jd.api.rest.ComJdJinVenderHandlerOpenStatementFacadeOrderSettlementListRequest import ComJdJinVenderHandlerOpenStatementFacadeOrderSettlementListRequest
from jd.api.rest.ComJdSellerOrderApiInformationFacadeGetOrderListRequest import ComJdSellerOrderApiInformationFacadeGetOrderListRequest
from jd.api.rest.ComJdSellerOrderApiInformationFacadeGetOrderDetailRequest import ComJdSellerOrderApiInformationFacadeGetOrderDetailRequest
from jd.api.rest.ComEpiPromoOpenApiWriteResumePromoRequest import ComEpiPromoOpenApiWriteResumePromoRequest
from jd.api.rest.ComProductUpdateApiServiceChangeSkuStatusRequest import ComProductUpdateApiServiceChangeSkuStatusRequest
from jd.api.rest.ComEpiPromoOpenApiWriteSuspendPromoRequest import ComEpiPromoOpenApiWriteSuspendPromoRequest
from jd.api.rest.ComProductQueryApiServiceQueryProductsRequest import ComProductQueryApiServiceQueryProductsRequest
from jd.api.rest.ComProductUpdateApiServiceChangeProductStatusRequest import ComProductUpdateApiServiceChangeProductStatusRequest
from jd.api.rest.ComJdEtmsWaybillApiGlscGlscWaybillTraceApiGetTraceInfoByOrderRequest import ComJdEtmsWaybillApiGlscGlscWaybillTraceApiGetTraceInfoByOrderRequest
from jd.api.rest.VenderGetVenderBrandByVenderIdForI18NRequest import VenderGetVenderBrandByVenderIdForI18NRequest
from jd.api.rest.ComJdThPopOpenOrderCancelFacadeSubmitCancelOrderRequest import ComJdThPopOpenOrderCancelFacadeSubmitCancelOrderRequest
from jd.api.rest.ComEpiCouponOpenApiWriteCloseCouponRequest import ComEpiCouponOpenApiWriteCloseCouponRequest
from jd.api.rest.ComJdSellerOrderApiCancelFacadeReviewRequest import ComJdSellerOrderApiCancelFacadeReviewRequest
from jd.api.rest.ComEpiCouponOpenApiWriteCreateCouponRequest import ComEpiCouponOpenApiWriteCreateCouponRequest
from jd.api.rest.ThSellerPopSearchStoreSkuListRequest import ThSellerPopSearchStoreSkuListRequest
from jd.api.rest.ThSellerPopSkuBindStoreRequest import ThSellerPopSkuBindStoreRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetTotalPricePromoRequest import ComEpiPromoOpenApiReadGetTotalPricePromoRequest
from jd.api.rest.ThSellerPopUpdateStoreSkuStatusRequest import ThSellerPopUpdateStoreSkuStatusRequest
from jd.api.rest.ComEpiPromoOpenApiWriteCreateUnitPromoRequest import ComEpiPromoOpenApiWriteCreateUnitPromoRequest
from jd.api.rest.ComEpiPromoOpenApiWriteCreateGiftPromoRequest import ComEpiPromoOpenApiWriteCreateGiftPromoRequest

==> jd-sdk-1.1.1.tar.gz: jd-sdk-1.1.1/jd/api/rest/__init__.py <==
from jd.api.rest.ComEpiPromoOpenApiWriteCreateSuitPromoRequest import ComEpiPromoOpenApiWriteCreateSuitPromoRequest
from jd.api.rest.ComJdStockShopGlobalWebOpenWarehouseFacadeAddStoreRequest import ComJdStockShopGlobalWebOpenWarehouseFacadeAddStoreRequest
from jd.api.rest.ComJdThPopOpenOrderDeliveryFacadeSplitOrderRequest import ComJdThPopOpenOrderDeliveryFacadeSplitOrderRequest
from jd.api.rest.ComJdThPopOpenOrderInformationFacadeQueryPaymentDetailInfoRequest import ComJdThPopOpenOrderInformationFacadeQueryPaymentDetailInfoRequest
from jd.api.rest.ComJdOverseaApiProductUpdateApiServiceRequest import ComJdOverseaApiProductUpdateApiServiceRequest
from jd.api.rest.ComJdSellerOrderApiDeliveryFacadeDeliveryRequest import ComJdSellerOrderApiDeliveryFacadeDeliveryRequest
from jd.api.rest.ComJdJinVenderHandlerOpenStatementFacadeStatementDetailRequest import ComJdJinVenderHandlerOpenStatementFacadeStatementDetailRequest
from jd.api.rest.ComJdOverseaApiProductUpdateApiServiceDeleteSkuRequest import ComJdOverseaApiProductUpdateApiServiceDeleteSkuRequest
from jd.api.rest.ComProductUpdateApiServiceUpdateSpuRequest import ComProductUpdateApiServiceUpdateSpuRequest
from jd.api.rest.VenderGetVenderCategoryByVenderIdI18NRequest import VenderGetVenderCategoryByVenderIdI18NRequest
from jd.api.rest.VenderSellerWebControllerOpenCompanyVenderCompanyFacadeGetCompanyByVenderIdRequest import VenderSellerWebControllerOpenCompanyVenderCompanyFacadeGetCompanyByVenderIdRequest
from jd.api.rest.ComJdThPopOpenOrderInformationFacadeListOrderRequest import ComJdThPopOpenOrderInformationFacadeListOrderRequest
from jd.api.rest.ComJdSellerOrderApiDeliveryFacadeSplitRequest import ComJdSellerOrderApiDeliveryFacadeSplitRequest
from jd.api.rest.ComProductUpdateApiServiceUpdateSkusRequest import ComProductUpdateApiServiceUpdateSkusRequest
from jd.api.rest.ThSellerPopUpdateStoreSkuPriceRequest import ThSellerPopUpdateStoreSkuPriceRequest
from jd.api.rest.ThSellerPopUpdateStoreSkuStockRequest import ThSellerPopUpdateStoreSkuStockRequest
from jd.api.rest.ComJdThPopOpenOrderPrintFacadePrintLabelRequest import ComJdThPopOpenOrderPrintFacadePrintLabelRequest
from jd.api.rest.ComJdSellerOrderApiPrintFacadePrintRequest import ComJdSellerOrderApiPrintFacadePrintRequest
from jd.api.rest.ComEpiCouponOpenApiReadCouponDetailRequest import ComEpiCouponOpenApiReadCouponDetailRequest
from jd.api.rest.ComProductUpdateApiServiceSaveProductRequest import ComProductUpdateApiServiceSaveProductRequest
from jd.api.rest.VenderGetVenderShopCategoryByVenderIdI18NRequest import VenderGetVenderShopCategoryByVenderIdI18NRequest
from jd.api.rest.ComProductQueryApiServiceQuerycategoryRequest import ComProductQueryApiServiceQuerycategoryRequest
from jd.api.rest.ComJdSellerOrderApiOperationFacadeAcceptOrderRequest import ComJdSellerOrderApiOperationFacadeAcceptOrderRequest
from jd.api.rest.ComJdIntlAsmShopAfsApiServiceQueryDetailRequest import ComJdIntlAsmShopAfsApiServiceQueryDetailRequest
from jd.api.rest.ComJdwlApiOrderTrackSiteJsfExportOrderTrackSiteExportAddIntlOrderTrackRequest import ComJdwlApiOrderTrackSiteJsfExportOrderTrackSiteExportAddIntlOrderTrackRequest
from jd.api.rest.ComJdSellerOrderApiOperationFacadeRecallOrderRequest import ComJdSellerOrderApiOperationFacadeRecallOrderRequest
from jd.api.rest.ComProductQueryApiServiceQueryskusRequest import ComProductQueryApiServiceQueryskusRequest
from jd.api.rest.ComJdSellerOrderApiOperationFacadeVerifyOrderRequest import ComJdSellerOrderApiOperationFacadeVerifyOrderRequest
from jd.api.rest.ComEpiPromoOpenApiWriteCreateSumPromoRequest import ComEpiPromoOpenApiWriteCreateSumPromoRequest
from jd.api.rest.ComEpiCouponOpenApiReadCouponListRequest import ComEpiCouponOpenApiReadCouponListRequest
from jd.api.rest.ComProductQueryApiServiceQueryProductByIdRequest import ComProductQueryApiServiceQueryProductByIdRequest
from jd.api.rest.JosVoucherInfoGetRequest import JosVoucherInfoGetRequest
from jd.api.rest.ComJdwlSellerAlphaOpenServiceGetDeliveryRecommendCarriersForOpenRequest import ComJdwlSellerAlphaOpenServiceGetDeliveryRecommendCarriersForOpenRequest
from jd.api.rest.ComEpiPromoOpenApiWriteDelPromoRequest import ComEpiPromoOpenApiWriteDelPromoRequest
from jd.api.rest.CommonImageUploadFileRequest import CommonImageUploadFileRequest
from jd.api.rest.ComJdThPopOpenOrderPrintFacadeGetOrderShippingListRequest import ComJdThPopOpenOrderPrintFacadeGetOrderShippingListRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetUnitPromoRequest import ComEpiPromoOpenApiReadGetUnitPromoRequest
from jd.api.rest.PopAdminExportQueryListNewRequest import PopAdminExportQueryListNewRequest
from jd.api.rest.ComJdPopVenderCenterI18nApiVenderVenderBasicFacadeGetVenderInfoByVenderIdRequest import ComJdPopVenderCenterI18nApiVenderVenderBasicFacadeGetVenderInfoByVenderIdRequest
from jd.api.rest.ComJdIntlAsmShopAfsApiServiceQueryAllRequest import ComJdIntlAsmShopAfsApiServiceQueryAllRequest
from jd.api.rest.JosMasterKeyGetRequest import JosMasterKeyGetRequest
from jd.api.rest.ComJdThPopOpenOrderInformationFacadeQueryOrderDetailRequest import ComJdThPopOpenOrderInformationFacadeQueryOrderDetailRequest
from jd.api.rest.I18nPlaceOrderServiceJsfGetPreWaybillCodeForOpenApiRequest import I18nPlaceOrderServiceJsfGetPreWaybillCodeForOpenApiRequest
from jd.api.rest.ComJdJinVenderHandlerOpenStatementFacadeListStatementRequest import ComJdJinVenderHandlerOpenStatementFacadeListStatementRequest
from jd.api.rest.ComJdAddressInternationalGlscGlscAddressCodingServiceWSGetChildrenRequest import ComJdAddressInternationalGlscGlscAddressCodingServiceWSGetChildrenRequest
from jd.api.rest.ComJdAddressInternationalGlscGlscAddressCodingServiceWSParseAddressCodingRequest import ComJdAddressInternationalGlscGlscAddressCodingServiceWSParseAddressCodingRequest
from jd.api.rest.JosSecretApiReportGetRequest import JosSecretApiReportGetRequest
from jd.api.rest.ComProductQueryApiServiceQuerySkusByOuterIdsRequest import ComProductQueryApiServiceQuerySkusByOuterIdsRequest
from jd.api.rest.ComJdAdwordApiServiceAdwordSellerApiServiceCreateAdwordForSkuRequest import ComJdAdwordApiServiceAdwordSellerApiServiceCreateAdwordForSkuRequest
from jd.api.rest.ComJdAdwordApiServiceAdwordSellerApiServiceQueryAdwordsBySkuIdRequest import ComJdAdwordApiServiceAdwordSellerApiServiceQueryAdwordsBySkuIdRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetPromoMainSkuRequest import ComEpiPromoOpenApiReadGetPromoMainSkuRequest
from jd.api.rest.ComJdAdwordApiServiceAdwordSellerApiServiceDeleteAdwordsBySkuIdRequest import ComJdAdwordApiServiceAdwordSellerApiServiceDeleteAdwordsBySkuIdRequest
from jd.api.rest.ComEpiBranchOpenApiReadBranchListRequest import ComEpiBranchOpenApiReadBranchListRequest
from jd.api.rest.StockUpdateSkuStockRequest import StockUpdateSkuStockRequest
from jd.api.rest.ComJdPopVenderCenterI18nApiBusinessBusinessCheckFacadeRequest import ComJdPopVenderCenterI18nApiBusinessBusinessCheckFacadeRequest
from jd.api.rest.ComJdSellerOrderApiInformationFacadeGetPromotionDetailRequest import ComJdSellerOrderApiInformationFacadeGetPromotionDetailRequest
from jd.api.rest.ComEpiBranchOpenApiReadBranchDetailRequest import ComEpiBranchOpenApiReadBranchDetailRequest
from jd.api.rest.ComEpiBranchOpenApiWriteBranchCreationRequest import ComEpiBranchOpenApiWriteBranchCreationRequest
from jd.api.rest.JingdongComEpiBranchOpenApiWriteBranchModifyRequest import JingdongComEpiBranchOpenApiWriteBranchModifyRequest
from jd.api.rest.StockAddWareStockRequest import StockAddWareStockRequest
from jd.api.rest.ComEpiBranchOpenApiWriteUpdateStatusRequest import ComEpiBranchOpenApiWriteUpdateStatusRequest
from jd.api.rest.ComJdSellerTrackApiTrackSynFacadeRequest import ComJdSellerTrackApiTrackSynFacadeRequest
from jd.api.rest.StockGetStoreListRequest import StockGetStoreListRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetGiftPromoRequest import ComEpiPromoOpenApiReadGetGiftPromoRequest
from jd.api.rest.PromotionPriceUpdateSkuPriceJsonWithVenderIdRequest import PromotionPriceUpdateSkuPriceJsonWithVenderIdRequest
from jd.api.rest.StockBatchQueryStockRequest import StockBatchQueryStockRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetSuitPromoRequest import ComEpiPromoOpenApiReadGetSuitPromoRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetPromoListForPageRequest import ComEpiPromoOpenApiReadGetPromoListForPageRequest
from jd.api.rest.ComJdPopVenderCenterI18nApiShopVenderShopFacadeGetVenderShopByVenderIdRequest import ComJdPopVenderCenterI18nApiShopVenderShopFacadeGetVenderShopByVenderIdRequest
from jd.api.rest.VenderSellerWebControllerOpenVenderAddrVenderAddrFacadeListVenderTakeAddressRequest import VenderSellerWebControllerOpenVenderAddrVenderAddrFacadeListVenderTakeAddressRequest
from jd.api.rest.VenderSellerWebControllerOpenVenderAddrVenderAddrFacadeListVenderReturnAddressRequest import VenderSellerWebControllerOpenVenderAddrVenderAddrFacadeListVenderReturnAddressRequest
from jd.api.rest.ComJdGmsGreatdaneCategoryServiceReadCategoryReadServiceGetCategorysRequest import ComJdGmsGreatdaneCategoryServiceReadCategoryReadServiceGetCategorysRequest
from jd.api.rest.ComJdJinVenderHandlerOpenStatementFacadeConfirmStatementRequest import ComJdJinVenderHandlerOpenStatementFacadeConfirmStatementRequest
from jd.api.rest.PopAdminExportOrderDeliveryNewRequest import PopAdminExportOrderDeliveryNewRequest
from jd.api.rest.ComJdJinVenderHandlerOpenStatementFacadeOrderSettlementListRequest import ComJdJinVenderHandlerOpenStatementFacadeOrderSettlementListRequest
from jd.api.rest.ComJdSellerOrderApiInformationFacadeGetOrderListRequest import ComJdSellerOrderApiInformationFacadeGetOrderListRequest
from jd.api.rest.ComJdSellerOrderApiInformationFacadeGetOrderDetailRequest import ComJdSellerOrderApiInformationFacadeGetOrderDetailRequest
from jd.api.rest.ComEpiPromoOpenApiWriteResumePromoRequest import ComEpiPromoOpenApiWriteResumePromoRequest
from jd.api.rest.ComProductUpdateApiServiceChangeSkuStatusRequest import ComProductUpdateApiServiceChangeSkuStatusRequest
from jd.api.rest.ComEpiPromoOpenApiWriteSuspendPromoRequest import ComEpiPromoOpenApiWriteSuspendPromoRequest
from jd.api.rest.ComProductQueryApiServiceQueryProductsRequest import ComProductQueryApiServiceQueryProductsRequest
from jd.api.rest.ComProductUpdateApiServiceChangeProductStatusRequest import ComProductUpdateApiServiceChangeProductStatusRequest
from jd.api.rest.ComJdEtmsWaybillApiGlscGlscWaybillTraceApiGetTraceInfoByOrderRequest import ComJdEtmsWaybillApiGlscGlscWaybillTraceApiGetTraceInfoByOrderRequest
from jd.api.rest.VenderGetVenderBrandByVenderIdForI18NRequest import VenderGetVenderBrandByVenderIdForI18NRequest
from jd.api.rest.ComJdThPopOpenOrderCancelFacadeSubmitCancelOrderRequest import ComJdThPopOpenOrderCancelFacadeSubmitCancelOrderRequest
from jd.api.rest.ComJdSellerOrderApiCancelFacadeSubmitRequest import ComJdSellerOrderApiCancelFacadeSubmitRequest
from jd.api.rest.ComEpiCouponOpenApiWriteCloseCouponRequest import ComEpiCouponOpenApiWriteCloseCouponRequest
from jd.api.rest.ComJdSellerOrderApiCancelFacadeReviewRequest import ComJdSellerOrderApiCancelFacadeReviewRequest
from jd.api.rest.ComEpiCouponOpenApiWriteCreateCouponRequest import ComEpiCouponOpenApiWriteCreateCouponRequest
from jd.api.rest.ThSellerPopSearchStoreSkuListRequest import ThSellerPopSearchStoreSkuListRequest
from jd.api.rest.ThSellerPopSkuBindStoreRequest import ThSellerPopSkuBindStoreRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetTotalPricePromoRequest import ComEpiPromoOpenApiReadGetTotalPricePromoRequest
from jd.api.rest.ThSellerPopUpdateStoreSkuStatusRequest import ThSellerPopUpdateStoreSkuStatusRequest
from jd.api.rest.ComEpiPromoOpenApiWriteCreateUnitPromoRequest import ComEpiPromoOpenApiWriteCreateUnitPromoRequest
from jd.api.rest.ComEpiPromoOpenApiWriteCreateGiftPromoRequest import ComEpiPromoOpenApiWriteCreateGiftPromoRequest
